trelawney package
=================

Submodules
----------

trelawney.base\_explainer module
--------------------------------

.. automodule:: trelawney.base_explainer
    :members:
    :undoc-members:
    :show-inheritance:

trelawney.colors module
-----------------------

.. automodule:: trelawney.colors
    :members:
    :undoc-members:
    :show-inheritance:

trelawney.lime\_explainer module
--------------------------------

.. automodule:: trelawney.lime_explainer
    :members:
    :undoc-members:
    :show-inheritance:

trelawney.logreg\_explainer module
----------------------------------

.. automodule:: trelawney.logreg_explainer
    :members:
    :undoc-members:
    :show-inheritance:

trelawney.shap\_explainer module
--------------------------------

.. automodule:: trelawney.shap_explainer
    :members:
    :undoc-members:
    :show-inheritance:

trelawney.surrogate\_explainer module
-------------------------------------

.. automodule:: trelawney.surrogate_explainer
    :members:
    :undoc-members:
    :show-inheritance:

trelawney.tree\_explainer module
--------------------------------

.. automodule:: trelawney.tree_explainer
    :members:
    :undoc-members:
    :show-inheritance:

trelawney.trelawney module
--------------------------

.. automodule:: trelawney.trelawney
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: trelawney
    :members:
    :undoc-members:
    :show-inheritance:
